@@ -32,6 +32,7 @@ public slots:
     void gpgDecryption();
     void gpgEncryption();
     void gpgDecode();
+    void gpgImportKey();
 
 private:
     QTextEdit *gpgText;
@@ -51,7 +52,7 @@ private:
     QPushButton *gpgKeyManagmentButton;
     QPushButton *gpgCreateKeysButton;
     QPushButton *gpgImportKeysButton;
-    QPushButton *gpgSetKeyButton;
+
     QProcess *gpg;
 };
 
